[Python-checkins] commit of r41890 - python/trunk/Tools/msi/msi.py

martin.v.loewis python-checkins at python.org
Tue Jan 3 07:29:55 CET 2006


Author: martin.v.loewis
Date: Tue Jan  3 07:29:53 2006
New Revision: 41890

Modified:
   python/trunk/Tools/msi/msi.py
Log:
Ignore .svn instead of CVS now.

Modified: python/trunk/Tools/msi/msi.py
==============================================================================
--- python/trunk/Tools/msi/msi.py	(original)
+++ python/trunk/Tools/msi/msi.py	Tue Jan  3 07:29:53 2006
@@ -907,7 +907,7 @@
     pydirs = [(root,"Lib")]
     while pydirs:
         parent, dir = pydirs.pop()
-        if dir == "CVS" or dir.startswith("plat-"):
+        if dir == ".svn" or dir.startswith("plat-"):
             continue
         elif dir in ["lib-tk", "idlelib", "Icons"]:
             if not have_tcl:
@@ -957,9 +957,9 @@
             lib.add_file("wininst-6.exe")
             lib.add_file("wininst-7.1.exe")
         if dir=="data" and parent.physical=="test" and parent.basedir.physical=="email":
             # This should contain all non-CVS files listed in CVS
             for f in os.listdir(lib.absolute):
-                if f.endswith(".txt") or f=="CVS":continue
+                if f.endswith(".txt") or f==".svn":continue
                 if f.endswith(".au") or f.endswith(".gif"):
                     lib.add_file(f)
                 else:
@@ -957,9 +957,9 @@
             lib.add_file("wininst-7.1.exe")
         if dir=="data" and parent.physical=="test" and parent.basedir.physical=="email":
-            # This should contain all non-CVS files listed in CVS
+            # This should contain all non-.svn files listed in subversion
             for f in os.listdir(lib.absolute):


More information about the Python-checkins mailing list